#
# spec file for package lftp
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           lftp
Version:        4.8.3
Release:        lp150.3.3.1
Summary:        Command Line File Transfer Program
License:        GPL-3.0+
Group:          Productivity/Networking/Ftp/Clients
URL:            http://lftp.yar.ru/
Source:         http://lftp.yar.ru/ftp/%{name}-%{version}.tar.xz
Source2:        http://lav.yar.ru/lav@yars.free.net-gpg-public-key#/%name.keyring
Source3:        http://lftp.yar.ru/ftp/%{name}-%{version}.tar.xz.asc
# PATCH-FEATURE-OPENSUSE lftp-ssl-cipher.patch pgajdos@suse.cz -- use stronger cipher [bnc#857148]
Patch0:         lftp-default-ssl-cipher.patch
# PATCH-FIX-UPSTREAM fix-for-upstream-sources.patch psimons@suse.com -- lftp hangs if uploading a 0 byte file [bsc#1079168]
Patch1:         https://github.com/lavv17/lftp/commit/b934dbba0cb3.patch#/fix-zero-byte-file-upload-via-ssl.patch
# PATCH-FEATURE-OPENSUSE patch2-patch6 psimons@suse.com -- maintained at https://github.com/opensuse/lftp [bsc#1083331]
Patch2:         0001-Add-content-of-the-SUSE-lftp-vi-1.1-archive.patch
Patch3:         0002-Add-content-of-lftp-compat-addfiles.patch.patch
Patch4:         0003-Add-content-of-lftp-completion.patch.patch
Patch5:         0004-Include-config.h-to-detect-gnulib-macros.patch
Patch6:         0005-Add-the-wrapper-code-to-the-Makefile-in-order-to-bui.patch
Patch7:         relax-ssh-password-prompt-recognition.patch
Patch8:         https://github.com/lavv17/lftp/commit/a27e07d90a4608ceaf928b1babb27d4d803e1992.patch#/CVE-2018-10916.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  ncurses-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  update-alternatives
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libidn2)
BuildRequires:  pkgconfig(zlib)
Requires:       less
Requires(post): update-alternatives
Requires(postun): update-alternatives
Conflicts:      ftp

%description
LFTP is a reliable shell-like command line FTP client. It can retry
operations and does reget automatically. It can do several transfers
simultaneously in the background. With LFTP, you can start a transfer
in the background and continue browsing that FTP site or another one.
This is all done in one process. Background jobs are completed in nohup
mode if you exit or close the modem connection. LFTP has reput, mirror,
and reverse mirror among its features. Since version 2.0, it also
supports the HTTP protocol. Other features include IPV6 support,
context sensitive completion, output redirection to files or to pipe,
FTP and HTTP proxy support, transfer rate throttling for each
connection and for all connections in sum, job queueing, job execution
at specified times, opie and skey support in the FTP protocol, SSL for
HTTP and FTP, and FXP transfers.

%prep
%setup -q
%autopatch -p1

%build
# It's necessary to update the Autotools build system, because of patches 2-6
# that we apply above.
gettextize --force --copy --no-changelog
autoreconf --install --force
%configure \
   --disable-silent-rules \
   --without-included-regex \
   --disable-static \
   --with-modules \
   --without-gnutls \
   --with-openssl \
   --with-debug \
   --without-profiling \
   --enable-largefile \
   --with-pager=%{_bindir}/less \
   --with-libidn2 \
   --with-expat \
   --disable-rpath
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -sf %{_sysconfdir}/alternatives/ftp %{buildroot}%{_bindir}/ftp
ln -sf %{_sysconfdir}/alternatives/ftp.1.gz %{buildroot}%{_mandir}/man1/ftp.1.gz
%suse_update_desktop_file %{name} -G "FTP client" Network FileTransfer
%find_lang %{name}

%post
/sbin/ldconfig
update-alternatives --install %{_bindir}/ftp ftp %{_bindir}/%{name}_wrapper 5 \
  --slave %{_mandir}/man1/ftp.1.gz ftp.1 %{_mandir}/man1/%{name}.1.gz

%postun
/sbin/ldconfig
if [ "$1" = 0 ] ; then
  update-alternatives --remove ftp %{_bindir}/%{name}_wrapper
fi

%files -f "lftp.lang"
%doc BUGS COPYING ChangeLog FAQ FEATURES README* NEWS THANKS TODO
%ghost %{_sysconfdir}/alternatives/ftp
%ghost %{_sysconfdir}/alternatives/ftp.1.gz
%{_bindir}/ftp
%{_mandir}/man1/ftp.1%{ext_man}
%config %{_sysconfdir}/lftp.conf
%{_bindir}/lftp
%{_bindir}/lftp_wrapper
%{_bindir}/lftpget
%{_datadir}/lftp
%dir %{_libdir}/lftp
%dir %{_libdir}/lftp/%{version}
%{_libdir}/lftp/%{version}/compat-mode.so
%{_libdir}/lftp/%{version}/cmd-mirror.so
%{_libdir}/lftp/%{version}/cmd-sleep.so
%{_libdir}/lftp/%{version}/cmd-torrent.so
%{_libdir}/lftp/%{version}/cmd-edit.so
%{_libdir}/lftp/%{version}/liblftp-network.so
%{_libdir}/lftp/%{version}/liblftp-pty.so
%{_libdir}/lftp/%{version}/proto-file.so
%{_libdir}/lftp/%{version}/proto-fish.so
%{_libdir}/lftp/%{version}/proto-ftp.so
%{_libdir}/lftp/%{version}/proto-http.so
%{_libdir}/lftp/%{version}/proto-sftp.so
%{_libdir}/liblftp-*.so
%{_libdir}/liblftp-*.so.*
%{_mandir}/man1/lftp.1%{ext_man}
%{_mandir}/man1/lftpget.1%{ext_man}
%{_mandir}/man5/lftp.conf.5%{ext_man}
%{_datadir}/applications/lftp.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/48x48
%dir %{_datadir}/icons/hicolor/48x48/apps
%{_datadir}/icons/hicolor/48x48/apps/lftp-icon.png

%changelog
* Wed Feb 27 2019 Peter Simons <psimons@suse.com>
- Add "relax-ssh-password-prompt-recognition.patch" to make sure
  the SSH login handling code detects password prompts more
  reliably. [bsc#1120946]
- Add "CVE-2018-10916.patch" to improve remote file name sanitizing
  code. This prevents remote attackers from tricking users to use
  reverse mirroring on an attacker-controlled FTP server, which
  would result in the removal of all files in the current working
  directory of the victim's system. [CVE-2018-10916, bsc#1103367].
* Fri Mar 16 2018 psimons@suse.com
- Added openSUSE-specific patches that implement a wrapper script
  called "ftp" on top of the lftp command that is compatible to
  lukemftp. Those patches are maintained in a fork of the upstream
  project at https://github.com/opensuse/lftp. [bsc#1083331]
  * 0001-Add-content-of-the-SUSE-lftp-vi-1.1-archive.patch
  * 0002-Add-content-of-lftp-compat-addfiles.patch.patch
  * 0003-Add-content-of-lftp-completion.patch.patch
  * 0004-Include-config.h-to-detect-gnulib-macros.patch
  * 0005-Add-the-wrapper-code-to-the-Makefile-in-order-to-bui.patch
* Wed Feb 28 2018 psimons@suse.com
- fix-zero-byte-file-upload-via-ssl.patch: fix a bug that caused
  lftp to break the TLS protocol and lose the connection when
  trying to upload a 0 byte length file. [bsc#1079168]
* Sat Nov 11 2017 aavindraa@gmail.com
- update to 4.8.3:
  * fixed 2 other core dumps on exit (incorrect order of deallocation).
  * fixed compilation with older C++ compilers.
* Wed Oct  4 2017 astieger@suse.com
- update to 4.8.2:
  * fixed a memory leak
  * fixed a core dump on exit
- includes changes from 4.8.1:
  * improved rate limiting to allow per-host limits
  * ftp: make prefer-epsv default "no"
  * ftp: fixed quote command and ftp:use-stat-for-list setting
  * switched to libidn2
  * fixed configure --disable-rpath
  * fixed coredump when a parent directory was deleted
- includes changes from 4.8.0:
  * mirror: improved performance of --scan-all-first for big trees
  * mirror: new --flat option to flatten the target directory structure
  * mmv: new command for file moving; redirect mv to mmv in certain cases
  * fixed compilation with newer openssl (1.1.0 and later)
  * du: allow multiple --exclude options to be combined
  * new setting cmd:nullglob for `glob' command prefix
  * http: use proppatch to set last-modified property
  * new settings net:connection-limit-timer and ftp:too-many-re
  * ftp: dynamically ajust connection limit
  * ftp: fixed core dump on LINK/SYMLINK when the command is not supported
  * get1: fixed -o option
  * sftp,fish: connect-program setting is now passed to the shell for execution
  * get/mget/put/mput: add -P option for parallel transfers and long options
  * fixed "local glob"
- build with libidn2
- package desktop file
* Wed Apr 26 2017 tchvatal@suse.com
- Version update to 4.7.7:
  * License has changed from GPL-2.0+ to GPL-3.0+
  * Various small fixes all around
- Remove all internal patches, if the ftp compat is needed we need
  to upstream it on github:
  * lftp-autoconf-req.patch
  * lftp-compat-addfiles.patch
  * lftp-completion.patch
  * lftp-config_h.patch
  * lftp-stdio.h.patch
  * lftp-vi.1.1.tar.gz
  * lftp-wrapper+edit+compat-modify.patch
- Pass all the configure arguments to ensure nothing gets automagically
  disabled
- Remove unused dependencies
* Wed Mar  1 2017 psimons@suse.com
- Fork lftp in SLE-12-SP3 to use the version from Factory to enable
  support for OpenSSL as requested in fate#321022. That change also
  obsoletes the following patches, which SLE previously required:
  * lftp-deal-gracefully-with-ipv6-failures.patch corresponds to
    upstream commit 58bfcfc2b00c and has been included since
    release 4.7.2 [bnc#975913].
  * lftp-ca-bundle-path.patch is necessary only when lftp was
    compiled against GNUTLS, but we use OpenSSL now [bnc#792456].
- Normalize spec file with spec-cleaner.
* Fri Nov 25 2016 idonmez@suse.com
- lftp 4.7.4:
  * mirror: new option --directory (-F) for source directories
    glob pattern.
  * mirror: fixed coredump with --depth-first + --recursion=newer.
  * mirror: create inaccessible directories anyway.
  * pget, torrent: avoid long delays in posix_fallocate(3) call.
  * new setting dns:name for host aliases.
  * ftp: allow SSL after certain types of ftp proxy.
  * http: fixed interpretation of links without a protocol.
  * cls: fixed glob metacharacter unquoting.
  * sftp: fixed mirroring of files with a leading tilde.
  * fixed transfer logging.
* Mon Aug  8 2016 asterios.dramis@gmail.com
- lftp 4.7.3:
  * mirror: don't add source directory base name to the target if
    the source ends with a slash.
  * mirror: fixed transfer count tracking in --scan-all-first mode.
  * new setting file:use-fallocate.
  * fixed "kill all" to remove queued commands.
  * fixed xfer:log-file setting to a writable file in a protected
    directory.
  * fixed xfer:clobber to allow output to non-plain files.
  * fixed mirror --Move to really keep source dir if it ends with a
    slash.
  From 4.7.2:
  * ftp: fixed loss of 17th file from MLSD listing.
  * new setting xfer:timeout.
  * ssl: improved ssl performance for small read sizes.
  * pget: allocate all needed disk space at once.
  * http: new settings http:use-range and hftp:use-range.
  * http: fixed setting http:authorization.
  * http: resolve redirections when getting files information.
  * http: include X-OC-MTime header in PUT requests for OwnCloud.
  * mirror: changed --Move option to keep source dir if it ends
    with a slash.
  * mirror: fixed timestamp mirroring when the source site sends
    redirections.
  * mirror: don't report errors when the target does not support
    chmod.
  * torrent: discard cached data after validating.
  * torrent: fixed a coredump on a file read error.
  * torrent: fixed closing oldest cached FD.
  * torrent/DHT: fixed our external IP voting.
  * torrent/DHT: black-list nodes which change node_id often.
  * torrent/DHT: black-list nodes which report many bad nodes.
  * torrent/DHT: ignore nodes with our own ID.
  * torrent/DHT: made node search more robust.
  * torrent/DHT: mark new nodes as questionable.
  * translations updated (zh_TW, ru).
- Added new build requirements libexpat-devel, libidn-devel and
  zlib-devel.
- Fixes for update-alternatives usage.
- Rebased lftp-wrapper+edit+compat-modify.patch to apply cleanly.
* Wed May 11 2016 moio@suse.com
- lftp 4.7.0:
  * ftp: add MODE Z support.
  * ftp: new settings ftp:use-mode-z, ftp:compressed-re, ftp:mode-z-level.
  * ftp: add MFF support for chmod.
  * ftp: prefer EPSV by default.
  * ftp: prefer CWD-relative paths.
  * ftp: enable MLSD by default (when supported).
  * ftp: assume AUTH is supported based on other newer features.
  * http: add support for digest authentication.
  * http: fixed webdav directory listing.
  * http: fixed a coredump when using a proxy for https.
  * sftp: fixed mirror to sftp with xfer:use-temp-file set.
  * ssl: optimized ssl for speed and lower syscall count.
  * ssl: log server's certificate fingerprint.
  * ssl: allow disabling certificate verification by its fingerprint.
  * get: rename backup file back if new file cannot be retrieved.
  * get: new settings xfer:backup-suffix and xfer:keep-backup.
  * get/put/mget/mput/pget/get1: add -q (quiet) option.
  * edit: allow creating a new file.
  * new debug option -T (truncate output file).
  * new mirror options: --{in,ex}clude-{rx,glob}-from.
  * new mirror options: --Remove-source-dirs, --Move.
- lftp 4.7.1:
  * http: fixed authentication for proxy, transient errors, max-retries=1.
  * http: fixed put with authentication not to use HEAD request.
  * translations updated (cs, ru).
* Mon Dec 14 2015 andreas@suse.de
- lftp 4.6.5:
  * sftp: fixed handling of out-of-order replies.
  * fixed futex_wait issue in SIGCHLD handler.
  * ftp: fixed ls freezing with unstable server connection.
  * torrent: show more correct ETA on the status line.
  * fixed gnutls priority string.
  * mirror: fixed excessive stack usage on large directories.
  * documented some hard to fix bugs.
  * improved man page on open command and cmd:prompt setting.
  * translations updated (zh_TW).
* Fri Aug 21 2015 astieger@suse.com
- lftp 4.6.4:
  * mirror: new option --transfer-all.
  * torrent: new setting torrent:timeout to limit time without any progress.
  * torrent: fixed handling of udp tracker without explicit port number.
  * torrent: improved transfer start time after metadata download.
  * improved sftp put -c to use a single FSETSTAT.
  * mirror --skip-noaccess now uses user name to check for permissions.
  * don't rename temporary file to the target name when transfer fails.
  * new cmd:prompt escapes \l and \L for local working directory.
* Fri Jun 19 2015 kstreitova@suse.com
- update to 4.6.3a
  * new mirror setting mirror:overwrite and options
  - -overwrite/--no-overwrite.
  * new mirror option --upload-older.
  * new mirror option --recursion={always,never,missing,newer}.
  * try to download zero sized files as they may be non-empty.
  * torrent: new options --only-new, --only-incomplete.
  * torrent: fixed endless loop in FD deallocation.
  * fixed a memleak when parsing a directory listing with special
    files.
  * fixed one byte buffer overflow in cls.
  * fixed cmd:fail-exit description in the man page.
  * fixed large stack usage when parsing fish directory listings.
- refresh lftp-stdio.h.patch
- use spec-cleaner
* Thu May 28 2015 idonmez@suse.com
- Update to version 4.6.2:
  * new command "edit" instead of the edit alias.
  * new setting ssl:priority for disabling selected protocols.
  * new settings fish:auto-confirm and sftp:auto-confirm.
  * new setting file:use-lock to lock local files before accessing.
  * ftp: fixed disconnecting on timeout (broken in 4.6.0).
  * http: enclose ipv6 address in brackets in URLs and Host header.
  * fixed mirror for http protocol with redirections.
  * fixed `bookmark edit' to use correct XDG path if XDG is used.
  * fixed a wildcard certificate validation vulnerability (CVE-2014-0139).
  * fixed proxy authentication for CONNECT method.
  * fixed exit code of `help' command.
  * fixed sftp to show file names with slashes.
  * fixed pget status display when all chunks are done except the first one.
- Drop lftp-CVE-2014-0139.patch, fixed upstream.
- Refresh lftp-default-ssl-cipher.patch
* Fri Jan  9 2015 andreas.stieger@gmx.de
- lftp 4.6.1:
  * new mirror option --scan-all-first.
  * mirror --Remove-source-files now removes files already present
    at the target.
  * added a workaround for FUSE with HadoopFS I/O error during
    rename(2).
  * fixed du to round file size up to block size.
  * fixed compilation with libressl.
  * fixed OPTS MLST, removed trailing semicolon.
  * fixed put to sftp with special files (like /dev/stdin).
  * fixed ftp to copy SID properly with GnuTLS
  * fixed mirror to follow redirections to files
* Thu Dec 11 2014 vcizek@suse.com
- build with openssl instead of gnutls as suggested in bnc#792456
  * don't default to /etc/ssl/ca-bundle.pem (bnc#907803)
  * drop lftp-ca-bundle-path.patch
- fix a "curl" vulnerability CVE-2014-0139
  * that's because lftp uses code borrowed from curl 7.21.3 which
    contains this incorrect wildcard certificate validation
  * added lftp-CVE-2014-0139.patch
* Mon Nov  3 2014 tchvatal@suse.com
- Fix the update-alternatives to be up-par
* Mon Nov  3 2014 tchvatal@suse.com
- Fully remove sle10 support.
* Mon Nov  3 2014 tchvatal@suse.com
- Version bump to lftp 4.6.0:
  * new torrent --share option.
  * new setting mirror:require-source.
  * new settings xfer:use-temp-file and xfer:temp-file-name.
  * ftp: wait for QUIT reply before closing control socket.
  * display valid IDN in URLs without percent encoding.
  * ftp: shutdown SSL connection before closing control socket.
  * ftp: avoid duplication of PROT command.
  * fixed debug -o to append to the log file.
  * fixed compilation without SSL.
  * http: don't uncompress files ending with .gz, .Z or .tgz
  * http: fixed inflation of some files.
  * minor fixes in torrent protocol.
* Thu Sep  4 2014 andreas.stieger@gmx.de
-lftp 4.5.5:
  * added support for internationalized domain names.
  * added lftp --norc option.
  * added mirror "Finished" message.
  * added ftp:catch-size setting.
  * fixed net:max-retries setting.
  * fixed byte counters in mirror status.
  * fixed a segfault in ftps.
  * fixed a spurious error message in fxp and ftp.
* Mon Aug 11 2014 andreas.stieger@gmx.de
- lftp 4.5.4:
  * new setting mirror:sort-by (name, size, date).
  * torrent: reduced cpu and memory usage.
  * fixed occasional "BUG:deadlock" message.
  * fixed a segfault when a directory contains duplicate file names.
  * fixed a memory leak in torrent.
  * fixed byte counters in mirror --depth-first.
  * fixed timeout checks in FISH.
  * translations updated (pl).
* Tue Jul 29 2014 pgajdos@suse.com
- use default ssl cipher instead of the custom one
  [bnc#857148] (internal)
- added patches:
  * lftp-default-ssl-cipher.patch
* Thu Jul 24 2014 andreas.stieger@gmx.de
- lftp 4.5.3:
  * new setting ftp:site.
  * don't uncompress http body when Contrent-Type is compressed.
  * check source address of DHT replies.
  * discard disconnected torrent peers only after a timeout.
* Thu Jun 12 2014 vdziewiecki@suse.com
- lftp 4.5.2:
  * fixed a coredump on startup when compiled with certain gcc
  versions.
  * mkdir -q option for quiet operation.
  * glob --exists and --not-exist options.
  * improved torrent status, show piece availability statistics.
  * remove unconnectable torrent peers on trackerless torrents.
* Thu Jun 12 2014 vdziewiecki@suse.com
- bnc#880202 - lftp_wrapper file corruption (modified
  lftp-compat-addfiles.patch - fix by pgajdos)
- Removed name from summary
* Sat Jun  7 2014 andreas.stieger@gmx.de
- lftp 4.5.1:
  * show piece availabilty in torrent status.
  * fixed a coredump in ftp when data connection fails.
  * fixed default values of some settings.
  * fixed http redirection handling.
  * fixed compilation with gcc-4.8.3.
* Mon Jun  2 2014 vdziewiecki@suse.com
- Removed desktop file - bnc#869644 - Remove lftp menu item
* Fri May 30 2014 andreas.stieger@gmx.de
- lftp 4.5.0:
  * optimized cpu usage for 10Gb/s transfers by using better data
    structures and algorithms.
  * new open option --env-password to take password from
    LFTP_PASSWORD environment variable.
  * new `exit parent' subcommand.
  * new settings http:accept-encoding, http:decode.
  * new setting xfer:max-log-size to limit transfer log size.
  * show last disconnect cause for a few seconds in the session
    status.
  * improved mirror status to display real-time aggregated byte
    count and rate.
  * save torrent matadata on disk and load if available when
    needed.
  * improved torrent DHT search.
  * fixed exit behavior to flush buffered commands.
  * fixed transfer rate reporting for mirror --parallel.
* Sat May 10 2014 andreas.stieger@gmx.de
- ltfp 4.4.16:
  * fixed mirror --loop to re-check base directory contents.
  * fixed sftp and fish authentication by password with FreeBSD
    server.
  * fixed directory index parsing for some http servers.
  * fixed find command output to avoid extra slash for plain files.
  * fixed several bugs which could cause segfault.
- some spec cleanup
* Thu Apr  3 2014 mpost@suse.com
- Modified lftp-wrapper+edit+compat-modify.patch. Fixes problem
  with "Unknown command open" when using the lftp_wrapper. bnc#867373
* Sun Feb  9 2014 andreas.stieger@gmx.de
- lftp 4.4.15:
  * new setting pget:min-chunk-size.
  * improved DHT search by preferring responded nodes.
  * allow UTC timezone in http timestamps.
  * fixed WebDAV rmdir operation.
  * fixed torrent hang on shutdown when a tracker is unresposive.
  * fixed adding too may slashes to URLs in http.
- verify source signatures
- fix SLE 11 SP3 build
* Wed Dec 18 2013 vdziewiecki@suse.com
-Update to latest stable upstream, 4.4.14:
    fixed HEAD/PROPFIND handling in http.
    a minor memory leak fixed.
* Fri Nov 29 2013 vdziewiecki@suse.com
-Update to latest stable upstream, 4.4.13:
    fixed a bug in file size checking code.
    new option -l (--ls) for find command.
    improve workaround for single NL replies from an FTP server.
    Ukrainian translation updated (Yuri Chornoivan).
    fixed spinning in "get" when no remote session is open.
    don't pre-fetch file information in "get" when not needed.
    fixed handling of 400/501 http codes for PROPFIND to switch to HEAD.
    fixed a crash after cls.
    added file size decrease checking.
    used a newer libtool for ppc64le platform.
* Mon Nov 18 2013 vdziewiecki@suse.com
-Update to latest stable upstream, 4.4.11:
    fixed a slow down in mirror from http (thanks to OGAWA Hirofumi).
    fixed a coredump in sftp when accessing an inexistent file.
  4.4.10 had these changes:
    mirror new option --file/-f to mirror a single file.
    mirror new option -O for get/put similarity.
    WebDAV fixes and improvements.
    new setting ftp:use-utf8 to disable utf-8 activation.
    fixed handling of incorrect encoding of file names.
    fixed compilation without libiconv.
    fixed occasional hang in mirror.
    kill ssh when terminating fish or sftp connection.
* Mon Oct  7 2013 pth@suse.de
- Update to latest stable 4.4.9:
  * implemented support for mirror -L in sftp.
  * pass all 3 std file descriptors when attaching to lftp instance.
  * ftp: added a workaround for incorrectly formatted multiline replies.
  * sftp: added a workaround for RouterOS v6.
  * fixed mirror --no-empty-dirs to skip directories with no included files.
  * fixed segfault when there is no TERM environment variable.
  * fixed torrent for meta-info files with %% in their names.
  * fixed compilation when IPV6_V6ONLY is not defined.
  * fixed compilation with older zlib.
  * fixed FD_CLOEXEC flag on cwd and transfer_log.
  * fixed MLSD parsing for semicolons in file names.
  * new translation: Ukrainian (thanks to Yuri Chornoivan).
  * man page updated.
  For the other changes since 4.4.0 see the file NEWS in the
  package documentation.
- Change source url as the old one isn't valid anymore.
- Use the xz packed tarbal because of size.
- Adapted patches:
  ftp-wrapper+edit+compat-modify.patch
  lftp-stdio.h.patch
- Add lftp-config_h.patch that includes config.h where needed
  to get the gnulib macros defined.
* Tue Jul  9 2013 schwab@suse.de
- Override broken configure checks
* Sun Mar 17 2013 dimstar@opensuse.org
- Fix lftp-ca-bundle-path.patch: the correct syntax is to "set" the
  parameter (bnc#792456).
* Sun Dec  2 2012 dimstar@opensuse.org
- Add lftp-ca-bundle-path.patch: use /etc/ssl/ca-bundle.pem as
  root CA store. Instead of 'suggesting' users to get used to
  certificate errors, it's better to give a working default that
  allows normal certificate verification. Note: we do not set
  ssl:ca-path, even though this would be nicer, but lftp v4.4.0
  seem not to support this (despite it being documented in man
  pages).
* Tue Oct 16 2012 puzel@suse.com
- update to 4.4.0
  * implemented bittorrent extensions (FAST, DHT, LTEP,
    ut_metadata, ut_pex).
  * allow torrent downloading by magnet links.
  * new setting torrent:use-dht.
  * new torrent option --dht-bootstrap for manual bootstrapping.
  * add support for name.utf-8 and path.utf-8 in torrent metadata.
  * now net:limit-rate and net:limit-total-rate settings can use suffixes,
    e.g. `set net:limit-total-rate 1M:500k'.
  * allow numeric user names.
  * don't try to upload if ALLO fails.
  * send PROT to ftp servers always when AUTH is activated.
  * fixed gnutls non-fatal error checking.
  * fixed execution of at-finish and at-queue-finish in certain cases.
  * fixed termcap coredump.
  * fixed opie on 64-bit machines.
  * treat gnutls decryption error as non-fatal.
  * fixed core dump in `bm:' pseudo-URL opening.
  * fixed PROPFIND result parsing (WebDAV).
* Fri Jul 27 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Fri Jul 13 2012 vcizek@suse.com
- mark alternative ftp.1 as ghost (bnc#723691)
* Wed May 30 2012 pascal.bleser@opensuse.org
- update to 4.3.7:
  * fixed script execution
  * cls fixed to show correct time always
  * torrent fixed for large PIDs
  * don't check hostname in openssl case with ssl:check-hostname off
* Mon May 21 2012 pascal.bleser@opensuse.org
- libgnutls-devel instead of gnutls-devel in order to build properly
  on the upcoming 12.2 and reflect the upstream naming change
* Sun Apr  1 2012 pascal.bleser@opensuse.org
- update to 4.3.6:
  * adds explicit retracker support (new setting torrent:retracker)
  * adds support for HTTP status code 429 Too Many Requests
  * improves FTP login error handling
  * fixes errors reported by -Werror=format-security
  * fixes HTTP error reporting
* Wed Jan 25 2012 pascal.bleser@opensuse.org
- update to 4.3.5:
  * fixed ascii mode uploads to sftp
  * fixed "local" command without arguments
  * fixed https
  * fixed large memory consumption in ftp when target disk is full
* Sun Jan  1 2012 pascal.bleser@opensuse.org
- update to 4.3.4:
  * new settings cmd:at-exit-bg, cmd:at-finish, cmd:at-queue-finish
  * added timestamps in readline history
  * improved attach command to remove stale sockets
  * fixed core dump when ftp server does not return valid PWD result
  * fixed a special ftp cd case when real cwd equals to the new cwd
  * fixed torrent status command line
  * fixed torrent to open files with CLOEXEC flag
  * fixed exit code of queue command
  * fixed mirror to follow local symlinks with -L option
  * fixed a crash with https
* Fri Oct 21 2011 pascal.bleser@opensuse.org
- update to lftp-4.3.3:
  - new setting ftp:use-tvfs (yes, no, auto)
  - improved ftp path handling for servers without TVFS feature
  - improved closure matching, now *.EXT matches URLs ending with ".EXT"
  - updated man page
  - updated translations
  - fixed mirror target directory naming
- merge with server:ftp/lftp:
  - add vi command support
  - fix build on SLE_11 and SLE_10
  - add .desktop file
* Wed Oct 12 2011 tabraham@novell.com
- update to lftp-4.3.2
  - fixed fish protocol syncronization when ls fails on the server
  - fixed torrent shutting down when the tracker fails
* Thu Jun 30 2011 puzel@novell.com
- update to lftp-4.3.1
  - fixed a coredump in torrent on linux with a ppp interface.
  - translation updated (ru).
* Mon Jun 27 2011 puzel@novell.com
- update to lftp-4.3.0
  - new command `attach' to control a backgrounded lftp.
  - automatically fill torrent:ipv6 setting.
  - slightly improved torrent status display.
  - fixed reconnect interval (it was sometimes uninitialized).
  - several fixes for the case of cmd:parallel>1 (Fernando
    Gutierrez).
* Fri May 13 2011 puzel@novell.com
- update to lftp-4.2.3
  - don't write passwords to transfer_log
  - new setting mirror:no-empty-dirs
  - allow `jobs' output to be redirected
  - don't list not connected torrent peers by default
  - show torrent validation rate and ETA
  - fixed `cd -'
  - fixed pget for URLs with special symbols
  - translations updated (cs, ru)
  - new setting ftp:use-ip-tos
  - optimized torrent validation
  - fixed fallocate call
  - got rid of sprintf calls
- drop lftp-missing-sentinel.patch (in upstream)
* Tue Mar 22 2011 puzel@novell.com
- update to lftp-4.2.0
  * changed ssl:verify-certificate default to yes.
  * check certificate common name in openssl case (code from curl).
  * disable weak algorithms in openssl (Ludwig Nussel
    <ludwig.nussel@suse.de>).
  * new setting xfer:log-file (Timur Sufiev).
  * support for netkey pasword in ftp ().
  * added torrent ipv6 support (new setting torrent:ipv6)
  * don't accept new connections when no torrent can accept them.
  * allow to specify job numbers in `jobs' command.
  * fixed a segfault in pget when an error happens on second chunk.
  Version 4.1.3
  * fixed a coredump in torrent (introduced in 4.1.2).
  Version 4.1.2
  * new command ln [-s], supported by FTP (SITE [SYM]LINK), FISH,
    SFTP, and locally via file: schema.
  * create remote symlinks in mirror -R if supported by server.
  * detect and remove duplicate peers in torrent.
- run spec-cleaner
- refresh patches
* Sun Nov 28 2010 puzel@novell.com
- udpate to 4.1.1
  * fixed job command line display.
  * fixed some warnings and compilation with old gcc compilers
  (Openwall).
* Tue Nov 23 2010 puzel@novell.com
- udpate to 4.1.0
  * send path components to ftp server separately, unless TVFS is
    in FEAT reply
  * save pget status at the very beginning of pget execution
  * allow mirror pget continuation (mirror -c --use-pget)
  * allow multiple torrent startup at once (e.g. torrent
  * .torrent)
  * pre-allocate disk space in torrent, if posix_fallocate(3) is
    supported
  * new command prefix `local'. It makes the following command use
    local session instead of remote
  * added torrent multi-tracker support
  * fixed convert-mozilla-cookies cookie duplication
* Fri Sep 17 2010 puzel@novell.com
- update to 4.0.10
  * use cached file set, don't parse file listing again
  * updated convert-netscape-cookies
  * fixed a problem with zeroed errno in http
  * fixed coredump on mirror --log=file when the file cannot be
    opened
  * translations updated (de, ru)
* Wed Jul 21 2010 puzel@novell.com
- update to 4.0.9
  * torrent: don't try to re-download invalid piece from the same
    peer
  * added a short lftp.conf(5) man page (Jiri Skala)
  * fixed a problem with zeroed errno (Gabriele Balducci)
  * fixed status of mget from file: schema
  * fixed a compilation problem on AIX (Claus K. Larsen)
* Thu May 27 2010 mkudlvasr@suse.cz
- update to 4.0.8
  highlights from changelist:
  * new settings: xfer:auto-rename (off by default),
    ftp:ssl-copy-sid (for some broken servers),
    cmd:stifle-rl-history (to limit command history size),
    ftp:prefer-epsv, ftp:trust-feat (default no),
    cmd:move-background-detach, ftp:proxy-auth-type
  * added torrent client
  * many bugs fixed
* Fri Feb 19 2010 puzel@novell.com
- lftp-use-pkg-config.patch, add pkg-config to BuildRequires
  - fixes build
- cleanup specfile
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Mar 23 2009 crrodriguez@suse.de
- fix build, missing sentinel
* Tue Feb 26 2008 crrodriguez@suse.de
- fix file-not-in-lang errors
- fix library-without-ldconfig* errors
* Wed Feb 13 2008 mkudlvasr@suse.cz
- update to 3.6.3
  highlights from changelist:
  * french and polish translations updated.
  * major code cleanup (using templates for reusable code - like lists)
  * new mirror options --on-change, --depth-first, --no-empty-dirs, --ascii,
  - -only-existing
  * lots of bugs fixed
- fixed compatibility mode to work with the code after cleanup
* Mon Jul 16 2007 mkudlvasr@suse.cz
- update to 3.5.11
  highlights from changelist:
  * fixed mirror for MDTM-less ftp servers.
  * fixed compilation with Sun native compiler
* Thu Apr  5 2007 mkudlvasr@suse.cz
- update to 3.5.10
  highlights from changelist:
  * fixed 'sleep' command
  * fixed 'mirror --script'
* Mon Mar 19 2007 mkudlvasr@suse.cz
- removed RPM_BUILD_ROOT from post-install script
* Tue Oct 17 2006 postadal@suse.cz
- updated to version 3.5.6
  * new settings cmd:parallel and cmd:queue-parallel to set number of jobs
    executed in parallel in non-interactive mode and in a queue.
  * new mirror option --skip-noaccess and setting mirror:skip-noaccess.
  * fixed a coredump when lftp was compiled with a non-gcc compiler.
  * fixed compilation when stdbool.h is missing.
  * fixed a failed assertion.
  * fixed coredump when doing `ls ..' on a http site.
  * fixed memory and file descriptor leak in mget/mput.
* Mon Aug 14 2006 anosek@suse.cz
- updated to version 3.5.4
  * new setting mirror:include-regex.
  * load ssl keys for protected data connection as well; use new option
    ftp:ssl-data-use-keys to disable it.
  * fixed human-readable options of du and cls.
  * fixed compilation on certain systems.
  * fixed a core dump in ftps with gnu tls.
  * fixed random queue duplication.
  * fixed compilation with modules and socks.
  * fixed installation with modules.
  * added configure --enable-packager-mode option
  * new setting mirror:include-regex.
  * load ssl keys for protected data connection as well; use new option
    ftp:ssl-data-use-keys to disable it.
  * fixed human-readable options of du and cls.
  * fixed compilation on certain systems.
* Tue Aug  1 2006 postadal@suse.cz
- updated to version 3.5.2
  * fixed lftp exit code when cmd:at-exit is set
  * new exit options: top, kill
  * new setting dns:max-retries
  * new settings fish:charset and sftp:charset (for sftp version<4)
  * implemented pget -c (continue) with a status file
  * new options of `repeat' command: --count (-c), --delay (-d),
  - -while-ok, --until-ok
  * added support for ALLO command and ftp:use-allo setting
  * changed default for http:use-propfind to no
* Fri Apr 14 2006 pnemec@suse.cz
- decreased priority of alternative system [#162595]
- another fix for lftp wrapper [#164726]
* Fri Apr  7 2006 pnemec@suse.cz
- fixed lftp_wrapper [#162595]
* Mon Mar 20 2006 postadal@suse.cz
- packaged %%ghost /usr/bin/ftp [#159341]
* Mon Mar 13 2006 postadal@suse.cz
- removed lukemftp from Obsoletes [#156450]
* Sat Mar 11 2006 postadal@suse.cz
- added ftp and ftp.1 to alternative system, so they can be
  interchanged with lukemftp [#156450]
* Thu Mar  9 2006 postadal@suse.cz
- fixed update problem (removed lukemftp from Conflicts) [#156450]
* Fri Mar  3 2006 pnemec@suse.cz
- fixed lukemftp update problem 154349
* Fri Jan 27 2006 pnemec@suse.cz
- fixed lftp_wrapper.c [#145143]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 pnemec@suse.cz
- fixed some parts in lftp_wrapper.c
* Tue Jan 17 2006 postadal@suse.cz
- made ftp wrapper and compat-mode module for backward compatibility
  with lukemftp [#52021] (compat-mode.patch, wrapper.patch)
- added -fstack-protector
* Sun Jan 15 2006 schwab@suse.de
- Don't strip binaries.
* Fri Jan  6 2006 postadal@suse.cz
- updated to version 3.4.0
* Wed Nov 23 2005 postadal@suse.cz
- updated to version 3.3.4
- parallelize build
* Thu Jul 28 2005 postadal@suse.cz
- updated to version 3.2.1
- disabled stripping in makefiles to enabling build helpful debuginfo package
- removed obsoleted gcc-sentinel-fix patch
* Wed Jan 19 2005 postadal@suse.cz
- updated to version 3.0.13
- fixed gcc warnings (gcc-sentinel-fix.diff)
* Tue Aug 17 2004 postadal@suse.cz
- removed /usr/bin/ftp link to avoid conflict with other ftp clients [#43765]
* Thu Aug  5 2004 postadal@suse.cz
- updated to version 3.0.6
* Fri Feb 13 2004 postadal@suse.cz
- updated to version 2.6.12
- removed obsoleted patches: http-empty-line-fix, http-overflow-fix
* Tue Feb 10 2004 schwab@suse.de
- Add readline-devel to neededforbuild.
* Tue Dec 16 2003 postadal@suse.cz
- fixed handling first empty line (server's response doesn't parse it correctly)
* Mon Dec  8 2003 postadal@suse.cz
- fixed remote exploitable buffer overflow while using HTTP/HTTPS [#33528]
* Thu Nov  6 2003 schwab@suse.de
- Fix quoting in configure script.
* Thu Sep 18 2003 postadal@suse.cz
- fixed to use stdarg [#30819]
* Wed Aug 20 2003 postadal@suse.cz
- removed forgotten __os_install_post
* Thu Jul 24 2003 postadal@suse.cz
- updated to version 2.6.6
* Mon Jun  2 2003 poeml@suse.de
- run automake
* Wed May 14 2003 mmj@suse.de
- Update to 2.6.5 including:
  * new mirror options --log=<file> and --script=<file> to produce
    lftp commands equivalent to the actions done (log) or to be
    done (script) by mirror. `-' as file name means stdout.
  * fixed a dead-lock when resuming FXP with passive source.
  * re-get file size and date after HTTP redirect.
  * added workarounds for proftpd.
  * handle EPIPE (Broken pipe) error as temporary network error.
  * fixed a dead-lock in HTTP retrieval after redirect.
  * added cls option --sort=date (Oskar Liljeblad).
  * fixed compilation on OpenBSD and older Solaris.
  * fixed handling of symbolic links in find.
  * lftp -f and -c options can now be combined
  * fixed slot handling in non-interactive mode.
  * fixed large file support in cat command.
  * fixed dante socks compilation.
  * fixed data connection abort with ssl connection to wu-ftpd.
- Remove files we don't want to package
* Fri Jan 10 2003 postadal@suse.cz
- updated to version 2.6.4
  * new settings net:socket-bind-ipv4 and net:socket-bind-ipv6 to bind sockets
    to a specific address (to select a specific network interface)
  * reget does not start transfer if not needed
  * ssl:verify-certificate set to no by default
  * fixed ~ handling in find and mirror
* Fri Dec  6 2002 postadal@suse.cz
- new package: lftp 2.6.3
